class OPTION:
    select = "SELECT"
    insert = "INSERT"
    insertMany = "ISM"
    update = "UPDATE"
    delete = "DELETE"


DEFAULT = {
    "host": "127.0.0.1",
    "port": 5432,
    "user": "postgres",
    "password": "123456"
}

DATABASES = {
    "default_database": "test",
    "data_database": "demo"
}
